import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'package:wordguessing/provider/data.dart';

class GameAbstract extends StatelessWidget {
  const GameAbstract({super.key});

  final int countWords = 4;

  void startGame(Data myProvider, String lang) {
    myProvider.updateLang(lang);
    nextWord(myProvider);
  }

  void nextWord(Data myProvider) {
    pickData(myProvider);
    myProvider.updateQuestionsCount(myProvider.questionsCount + 1);
  }

  void pickData(Data myProvider) {}

  void checkWord(Data myProvider, word) {
    if (myProvider.word?.key == word.key) {
      myProvider.updateGoodAnswers(myProvider.goodAnswers + 1);
      nextWord(myProvider);
    } else {
      myProvider.updateWrongAnswers(myProvider.wrongAnswers + 1);
    }
  }

  Widget buildScoreItemContainer(String text, Color blockColor) {
    // Darken block color to get border color
    const double amount = 0.2;
    final hsl = HSLColor.fromColor(blockColor);
    final hslDark = hsl.withLightness((hsl.lightness - amount).clamp(0.0, 1.0));
    final Color borderColor = hslDark.toColor();

    return Container(
      margin: const EdgeInsets.symmetric(horizontal: 15),
      padding: const EdgeInsets.all(5),
      decoration: BoxDecoration(
        color: blockColor,
        borderRadius: BorderRadius.circular(4),
        border: Border.all(
          color: borderColor,
          width: 4,
        ),
      ),
      child: Text(
        text,
        style: const TextStyle(
          fontSize: 25,
          fontWeight: FontWeight.w600,
          color: Colors.black,
        ),
      ),
    );
  }

  String getGoodAnswersString(Data myProvider) {
    final int count = myProvider.questionsCount - 1;
    return '👍 ${myProvider.goodAnswers}/$count';
  }

  String getWrongAnswersString(Data myProvider) {
    final int count = myProvider.questionsCount - 1;
    return '🚩 ${myProvider.wrongAnswers}/$count';
  }

  Widget buildScoreContainer(Data myProvider) {
    return Container(
      padding: const EdgeInsets.all(5),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          buildScoreItemContainer(
            getGoodAnswersString(myProvider),
            Colors.green,
          ),
          const SizedBox(width: 20),
          buildScoreItemContainer(
            getWrongAnswersString(myProvider),
            Colors.orange,
          ),
        ],
      ),
    );
  }

  Widget buildStartGameBlock(Data myProvider) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        ElevatedButton(
          style: ElevatedButton.styleFrom(
            foregroundColor: Colors.teal,
            backgroundColor: Colors.teal,
            padding: const EdgeInsets.all(35),
          ),
          child: const Text(
            "🇫🇷",
            style: TextStyle(
              fontSize: 60,
              color: Colors.black,
            ),
          ),
          onPressed: () => startGame(myProvider, 'fr'),
        ),
        const SizedBox(height: 15),
        ElevatedButton(
          style: ElevatedButton.styleFrom(
            foregroundColor: Colors.teal,
            backgroundColor: Colors.teal,
            padding: const EdgeInsets.all(35),
          ),
          child: const Text(
            "🇬🇧",
            style: TextStyle(
              fontSize: 60,
              color: Colors.black,
            ),
          ),
          onPressed: () => startGame(myProvider, 'en'),
        ),
      ],
    );
  }

  List<Widget> buildPageContent(Data myProvider) {
    return <Widget>[];
  }

  Widget buildPage(BuildContext context) {
    final Data myProvider = Provider.of<Data>(context);

    return SizedBox.expand(
      child: FittedBox(
        fit: BoxFit.contain,
        alignment: Alignment.center,
        child: SizedBox(
          height: (MediaQuery.of(context).size.height),
          width: (MediaQuery.of(context).size.width),
          child: Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisSize: MainAxisSize.max,
              children: buildPageContent(myProvider),
            ),
          ),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return buildPage(context);
  }
}
